import numpy as np
import matplotlib.pyplot as plt
import matplotlib
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

datfile = 'J161634.36+541011.51_1428562506980546688_Fuji_bin0p2.dat'

wave, flux, error = np.genfromtxt(datfile, unpack = True)

#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 14, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (9,2.5))
axes1 = fig.add_axes([0,0,1,1])
axes3 = fig.add_axes([0.58,0.5,0.4,0.45])

##################################################
xmajorLocator   = MultipleLocator(500)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(100)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(5)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(1)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)

##################################################
xmajorLocator   = MultipleLocator(200)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(50)
axes3.xaxis.set_major_locator(xmajorLocator)
axes3.xaxis.set_major_formatter(xmajorFormatter)
axes3.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(2)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(0.5)
axes3.yaxis.set_major_locator(ymajorLocator)
axes3.yaxis.set_major_formatter(ymajorFormatter)
axes3.yaxis.set_minor_locator(yminorLocator)

axes1.set_xlim(3700,6999)
axes1.set_ylim(9, 35)
axes3.set_xlim(6310,6790)
axes3.set_ylim(11,15)

axes1.axvline(3970,color='C1',lw=1.5,zorder=0, ymin = 0.05, ymax = 0.1)
axes1.axvline(4102,color='C1',lw=1.5,zorder=0, ymin = 0.05, ymax = 0.1)
axes1.axvline(4341,color='C1',lw=1.5,zorder=0, ymin = 0.05, ymax = 0.1)
axes1.axvline(4861,color='C1',lw=1.5,zorder=0, ymin = 0.05, ymax = 0.1)
axes1.axvline(6563,color='C1',lw=1.5,zorder=0, ymin = 0.05, ymax = 0.1)
a = axes1.axvline(10000, color='C1', label = r'H\,{\textsc{i}}')
axes1.text(0.03, 0.05, r'H\,{\textsc{i}}', transform=axes1.transAxes, color = 'C1')

axes1.set_xlabel('Wavelength(\AA)')
axes1.set_ylabel('Flux (10$^{-17}$\,ergs\,s$^{-1}$\,cm$^{-2}$\,\AA$^{-1}$)')
axes1.plot(wave, flux, color = '0.3', lw = 0.75)
axes3.plot(wave, flux, color = '0.3', lw = 0.75)
plt.savefig('WDJ1616+5410_spectrum_one.pdf', bbox_inches = 'tight')
plt.show()
plt.close()



