import numpy as np
import glob
import sys
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

oid,expid,hjd,mjd,mag,magerr,catflags,filtercode,ra,dec,chi,sharp,filefracday,field,ccdid,qid,limitmag,magzp,magzprms,clrcoeff,clrcounc,exptime,airmass,programid = np.genfromtxt('J161634.36+541011.51.csv', unpack = True, delimiter = ',', skip_header = 1, dtype = 'U')
hjd    = hjd.astype(float)
mag    = mag.astype(float)
magerr = magerr.astype(float)

hjd -= 2458180

hjd_g, hjd_r = hjd[filtercode == 'zg'], hjd[filtercode == 'zr']
mag_g, mag_r = mag[filtercode == 'zg'], mag[filtercode == 'zr']
magerr_g, magerr_r = magerr[filtercode == 'zg'], magerr[filtercode == 'zr']



#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 18, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (10,4))
axes1 = fig.add_axes([0,0,1,1])

#################################################
xmajorLocator   = MultipleLocator(200)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(50)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.05)
ymajorFormatter = FormatStrFormatter('%.2f')
yminorLocator   = MultipleLocator(0.01)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)
#################################################
axes1.set_xlabel('HJD -- 2458180.0 (d)')
axes1.set_ylabel('Magnitude')

axes1.set_xlim(0.01, 1499)
axes1.set_ylim(18.499, 18.101)

axes1.errorbar(hjd_g, mag_g, magerr_g, fmt = 'o', markersize = 2, elinewidth=0.15, color = 'C2')
axes1.errorbar(hjd_r, mag_r, magerr_r, fmt = '^', markersize = 2, elinewidth=0.15, color = 'C1')

axes1.axhline(np.median(mag_g),color = 'C2', ls = '--', lw =1, zorder = -0.5)
axes1.axhline(np.median(mag_r),color = 'C1', ls = '--', lw =1, zorder = -0.5)

r = axes1.scatter(-1000,-1000, marker = '^', color = 'C1', label = 'ZTF $r$')
g = axes1.scatter(-1000,-1000, marker = 'o', color = 'C2', label = 'ZTF $g$')
axes1.legend()

plt.savefig('ZTF_lightcurve.pdf', bbox_inches = 'tight')
plt.show()
plt.close()
