import numpy as np
import glob
import sys
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

jd1, hc1, mag1, error1 = np.genfromtxt('wdj1616+5410_20220526_lt_g.dat', unpack = True, skip_header = 2)
jd2, hc2, mag2, error2 = np.genfromtxt('wdj1616+5410_20220528_lt_g.dat', unpack = True, skip_header = 2)
jd3, hc3, mag3, error3 = np.genfromtxt('wdj1616+5410_20220531_lt_g.dat', unpack = True, skip_header = 2)

hjd1 = jd1 + hc1
hjd2 = jd2 + hc2
hjd3 = jd3 + hc3

# zeropoint
zeropoint = 2459726.5

hjd1 -= zeropoint
hjd2 -= zeropoint
hjd3 -= zeropoint


#using xlims to work out size of plot for consistent x axis
xlim11, xlim12 = 0.035, 0.210
xlim21, xlim22 = 2.005, 2.0675
xlim31, xlim32 = 4.98, 5.16

width1 = xlim12 - xlim11
width2 = xlim22 - xlim21
width3 = xlim32 - xlim31
total = width1 + width2 + width3

#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 18, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (12,5))
axes1 = fig.add_axes([0,0,width1/total,1])
axes2 = fig.add_axes([(width1)/total,0,width2/total,1])
axes3 = fig.add_axes([(width1+ width2)/total,0,width3/total,1])
##################################################
xmajorLocator   = MultipleLocator(0.02)
xmajorFormatter = FormatStrFormatter('%.2f')
xminorLocator   = MultipleLocator(0.005)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.02)
ymajorFormatter = FormatStrFormatter('%.2f')
yminorLocator   = MultipleLocator(0.005)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)

xmajorLocator   = MultipleLocator(0.02)
xmajorFormatter = FormatStrFormatter('%.2f')
xminorLocator   = MultipleLocator(0.005)
axes2.xaxis.set_major_locator(xmajorLocator)
axes2.xaxis.set_major_formatter(xmajorFormatter)
axes2.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.02)
ymajorFormatter = FormatStrFormatter('%.2f')
yminorLocator   = MultipleLocator(0.005)
axes2.yaxis.set_major_locator(ymajorLocator)
axes2.yaxis.set_major_formatter(ymajorFormatter)
axes2.yaxis.set_minor_locator(yminorLocator)

xmajorLocator   = MultipleLocator(0.02)
xmajorFormatter = FormatStrFormatter('%.2f')
xminorLocator   = MultipleLocator(0.005)
axes3.xaxis.set_major_locator(xmajorLocator)
axes3.xaxis.set_major_formatter(xmajorFormatter)
axes3.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.02)
ymajorFormatter = FormatStrFormatter('%.2f')
yminorLocator   = MultipleLocator(0.005)
axes3.yaxis.set_major_locator(ymajorLocator)
axes3.yaxis.set_major_formatter(ymajorFormatter)
axes3.yaxis.set_minor_locator(yminorLocator)
##################################################
#axes1.set_xlabel('HJD -- {:.1f} (d)'.format(zeropoint))
axes2.set_xlabel('HJD -- {:.1f} (d)'.format(zeropoint))
#axes3.set_xlabel('HJD -- {:.1f} (d)'.format(zeropoint))
axes1.set_ylabel('$g$ magnitude')
axes2.yaxis.set_ticklabels([])
axes3.yaxis.set_ticklabels([])
plt.setp(axes3.get_xticklabels()[1], visible=False)


axes1.set_xlim(xlim11, xlim12)
axes2.set_xlim(xlim21, xlim22)
axes3.set_xlim(xlim31, xlim32)
axes1.set_ylim(18.5,18.29)
axes2.set_ylim(18.5,18.29)
axes3.set_ylim(18.5,18.29)

axes1.text(0.7, 0.05, "2022\,-\,05\,-\,26", transform=axes1.transAxes, color = '0.1', fontsize = 20)
axes2.text(0.15, 0.05, "2022\,-\,05\,-\,28", transform=axes2.transAxes, color = '0.1', fontsize = 20)
axes3.text(0.7, 0.05, "2022\,-\,05\,-\,31", transform=axes3.transAxes, color = '0.1', fontsize = 20)

axes1.errorbar(hjd1, mag1, error1, fmt = 'o', markersize = 3, color = '0.3')
axes2.errorbar(hjd2, mag2, error2, fmt = 'o', markersize = 3, color = '0.3')
axes3.errorbar(hjd3, mag3, error3, fmt = 'o', markersize = 3, color = '0.3')

jd, hc, mag, error = np.genfromtxt('LT_Boris_lightcurve.dat', unpack = True, skip_header = 2)
axes1.axhline(np.median(mag), color = '0.5', lw = 0.5, ls = '--')
axes2.axhline(np.median(mag), color = '0.5', lw = 0.5, ls = '--')
axes3.axhline(np.median(mag), color = '0.5', lw = 0.5, ls = '--')

plt.savefig('LT_Boris_lightcurve.pdf', bbox_inches = 'tight')
plt.show()
plt.close()
