import numpy as np
import glob
import sys
import matplotlib
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

def spec_bin(w, f, e, bin_width):
  """Bins a spectrum with a resolution of bin_width"""
  if w[0] < 1000.0:
    w[:,0] *= 10
  wav_range   = max(w) - min(w)
  num_of_bins = int( np.ceil(wav_range / bin_width) )
  wb   = np.zeros(num_of_bins)
  fb   = np.zeros(num_of_bins)
  eb   = np.zeros(num_of_bins)
  temp = min(w) + (bin_width*0.5)
  for i in range(num_of_bins):
    if f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))].size != 0:
      flux_range    = f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      err_range     = e[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      wb[i], fb[i]  = temp, np.sum(flux_range*(err_range*(1/err_range.mean()))**-2)/np.sum((err_range*(1/err_range.mean()))**-2)
      eb[i]         = np.sqrt(1/np.sum(err_range**-2))
    temp          = temp + bin_width
  #
  return wb[((wb != 0) & (fb != 0) & (eb != 0))], fb[((wb != 0) & (fb != 0) & (eb != 0))], eb[((wb != 0) & (fb != 0) & (eb != 0))]
  


#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 16, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (6,4))
axes1 = fig.add_axes([0,0,0.5,1])
axes2 = fig.add_axes([0.5,0,0.5,1])

##################################################
xmajorLocator   = MultipleLocator(100)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(25)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(1)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(0.2)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)
##################################################
##################################################
xmajorLocator   = MultipleLocator(200)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(50)
axes2.xaxis.set_major_locator(xmajorLocator)
axes2.xaxis.set_major_formatter(xmajorFormatter)
axes2.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(1)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(0.2)
axes2.yaxis.set_major_locator(ymajorLocator)
axes2.yaxis.set_major_formatter(ymajorFormatter)
axes2.yaxis.set_minor_locator(yminorLocator)
##################################################

#axes1.set_xlim(3500, 10000)
axes1.set_xlim(4660, 5049.99)
axes2.set_xlim(6140, 6990)
axes1.axvline(4861, color = '0.5', lw = 0.8, ls = '--')
axes2.axvline(6563, color = '0.5', lw = 0.8, ls = '--')
axes2.yaxis.set_ticklabels([])

axes1.set_xlabel('Wavelength (\AA)')
axes2.set_xlabel('Wavelength (\AA)')
axes1.set_ylabel('B (MG)')

spec3_b = 'Hbeta_J161634.36+541011.51_39633311974295183-20210314-00080505-4903-b_norm.dat'
spec3_r = 'Halpha_J161634.36+541011.51_39633311974295183-20210314-00080505-4903-r_norm.dat'
spec4_b = 'Hbeta_J161634.36+541011.51_39633311974295183-20210314-00080506-4903-b_norm.dat'
spec4_r = 'Halpha_J161634.36+541011.51_39633311974295183-20210314-00080506-4903-r_norm.dat'

spec12_b = 'Hbeta_J161634.36+541011.51_39633311974295183-20210503-00087122-4921-b_norm.dat'
spec12_r = 'Halpha_J161634.36+541011.51_39633311974295183-20210503-00087122-4921-r_norm.dat'

wav3b, flux3b, err3b = np.genfromtxt(spec3_b, unpack = True)
wav3r, flux3r, err3r = np.genfromtxt(spec3_r, unpack = True)
wav4b, flux4b, err4b = np.genfromtxt(spec4_b, unpack = True)
wav4r, flux4r, err4r = np.genfromtxt(spec4_r, unpack = True)
wav12b, flux12b, err12b = np.genfromtxt(spec12_b, unpack = True)
wav12r, flux12r, err12r = np.genfromtxt(spec12_r, unpack = True)

mag1, mag2, mag3 = 3.50, 6.5, 4.33

pw3b, pf3b, pe3b = spec_bin(wav3b, flux3b, err3b, 2)
pw3r, pf3r, pe3r = spec_bin(wav3r, flux3r, err3r, 2)
pw4b, pf4b, pe4b = spec_bin(wav4b, flux4b, err4b, 2)
pw4r, pf4r, pe4r = spec_bin(wav4r, flux4r, err4r, 2)
pw12b, pf12b, pe12b = spec_bin(wav12b, flux12b, err12b, 2)
pw12r, pf12r, pe12r = spec_bin(wav12r, flux12r, err12r, 2)

axes1.plot(pw3b, pf3b*mag2, color = '0.3', lw = 0.8)
axes2.plot(pw3r, pf3r*mag2, color = '0.3', lw = 0.8)
axes1.axhline(mag2, color = '0.3', lw = 0.8, ls = '--')
axes2.axhline(mag2, color = '0.3', lw = 0.8, ls = '--')
axes1.plot(pw4b, pf4b*mag1, color = '0.3', lw = 0.8)
axes2.plot(pw4r, pf4r*mag1, color = '0.3', lw = 0.8)
axes1.plot(pw12b, pf12b*mag3, color = '0.3', lw = 0.8)
axes2.plot(pw12r, pf12r*mag3, color = '0.3', lw = 0.8)
axes1.axhline(mag1, color = '0.3', lw = 0.8, ls = '--')
axes2.axhline(mag1, color = '0.3', lw = 0.8, ls = '--')
axes1.axhline(mag3, color = '0.3', lw = 0.8, ls = '--')
axes2.axhline(mag3, color = '0.3', lw = 0.8, ls = '--')
axes1.set_ylim(2.7, 8)
axes2.set_ylim(2.7, 8)

axes1.text(0.03, 0.93, r'H$\beta$', transform=axes1.transAxes, color = '0.3' )
axes2.text(0.03, 0.93, r'H$\alpha$', transform=axes2.transAxes, color = '0.3')


axes1.text(0.03, 0.85, r'\#3', transform=axes1.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes2.text(0.03, 0.85, r'\#3', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes1.text(0.03, 0.03, r'\#4', transform=axes1.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes2.text(0.03, 0.03, r'\#4', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes1.text(0.03, 0.40, r'\#12', transform=axes1.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes2.text(0.03, 0.40, r'\#12', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})

axes2.text(0.66, 0.85, r'$B = 6.5$\,MG', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1}, fontsize = 13)
axes2.text(0.66, 0.40, r'$B = 4.3$\,MG', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1}, fontsize = 13)
axes2.text(0.66, 0.03, r'$B = 3.5$\,MG', transform=axes2.transAxes, color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1}, fontsize = 13)


for i in range(1,15):
  w, B = np.genfromtxt('alpha_{:d}.txt'.format(i), unpack = True)
  axes2.plot(w,B,lw = 0.5, color = 'C1', zorder = -5, alpha = 0.5)
for i in range(1,18):
  w, B = np.genfromtxt('beta_{:d}.txt'.format(i), unpack = True)
  axes1.plot(w,B,lw = 0.5, color = 'C0', zorder = -5, alpha = 0.5)


plt.savefig('spectra_3_and_4_and_12_new.pdf', bbox_inches = 'tight')
plt.show()
plt.close()