import numpy as np
import glob
import random
import sys
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter
from astropy.timeseries import LombScargle
import scipy.optimize

def gauss(x, a, b, c):
  return a*np.exp(-1*((x-b)/(2*c))**2)

jd, hc, mag_LT, error_LT = np.genfromtxt('LT_Boris_lightcurve.dat', unpack = True, skip_header = 2)
hjd_LT = jd + hc
dmag_LT = mag_LT - np.median(mag_LT)

oid,expid,hjd,mjd,mag,magerr,catflags,filtercode,ra,dec,chi,sharp,filefracday,field,ccdid,qid,limitmag,magzp,magzprms,clrcoeff,clrcounc,exptime,airmass,programid = np.genfromtxt('J161634.36+541011.51.csv', unpack = True, delimiter = ',', skip_header = 1, dtype = 'U')
hjd    = hjd.astype(float)
mag    = mag.astype(float)
magerr = magerr.astype(float)


hjd_ztf    = hjd[filtercode == 'zg']
mag_ztf    = mag[filtercode == 'zg']
magerr_ztf = magerr[filtercode == 'zg']
dmag_ztf = mag_ztf - np.median(mag_ztf)

hjd_ztf_r    = hjd[filtercode == 'zr']
mag_ztf_r    = mag[filtercode == 'zr']
magerr_ztf_r = magerr[filtercode == 'zr']
dmag_ztf_r = mag_ztf_r - np.median(mag_ztf_r)

hjd = np.append(hjd_ztf, hjd_LT)
mag = np.append(mag_ztf, mag_LT)
error = np.append(magerr_ztf, error_LT)
dmag = np.append(dmag_ztf, dmag_LT)

freq = np.arange(1, 100, 0.00005)

ls = LombScargle(hjd, dmag, error)

power = ls.power(freq)
power_r = LombScargle(hjd_ztf_r, dmag_ztf_r, magerr_ztf_r).power(freq)

#### Period from ZTF + LT g band

power2 = power[(freq > 30.223690) & (freq < 30.224147)]
freq2 = freq[(freq > 30.223690) & (freq < 30.224147)]
guesses = [0.6,30.223836,0.00012]
params, covar = scipy.optimize.curve_fit(gauss, freq2, power2, p0 = guesses, bounds=(0, [np.inf, np.inf, np.inf]))
print(params)
y = gauss(freq, params[0], params[1], params[2])

d = 1/params[1]
d_e = d*d*params[2]
d_e2 = d*d*covar[1][1]**0.5
period = d*24*60
p_e = d_e *24*60
p_e2 = d_e2 *24*60
print(period, p_e)
print("Std.dev. error: Period = {:.10f} $\pm$ {:.10f} minutes".format(period, p_e))


############################
# Getting period from r data
############################
power2 = power_r[(freq > 30.223533) & (freq < 30.224258)]
freq2 = freq[(freq > 30.223533) & (freq < 30.224258)]

guesses = [0.37,30.223836,0.0012]
params_r, covar_r = scipy.optimize.curve_fit(gauss, freq2, power2, p0 = guesses, maxfev = 20000, bounds=(0, [np.inf, np.inf, np.inf]))
print(params_r)
y = gauss(freq, params_r[0], params_r[1], params_r[2])

freq_r = params_r[1]
d = 1/params_r[1]
d_e = d*d*params_r[2]
period_r = d*24*60
p_e_r = d_e *24*60
print(period_r, p_e_r)
print("Std.dev. error: Period = {:.10f} $\pm$ {:.10f} minutes".format(period_r, p_e_r))



#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 20, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (13,5))
axes1 = fig.add_axes([0,0,1,1])

##################################################
xmajorLocator   = MultipleLocator(10)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(2)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.1)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.02)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)

axes1.set_xlim(1, 100)
axes1.set_ylim(0, 0.65)

axes1.set_xlabel('Frequency (d$^{-1}$)')
axes1.set_ylabel('Power')
axes1.axvline(params[1], color = '0.7', lw = 1, ls = '--')
axes1.axvline(params[1]/2.0, color = 'C0', lw = 1, ls = '--')
axes1.plot(freq, power, color = '0.3', lw = 0.75)
axes1.plot(freq, power_r, color = 'C1', lw = 0.75, alpha = 0.5)
axes1.text(0.66, 0.9,  r" P$_g$ = {:.4f} $\pm$ {:.4f} min".format(period, p_e), transform=axes1.transAxes, color = '0.1', fontsize = 20)
axes1.text(0.65, 0.76, r"2P$_g$ = {:.4f} $\pm$ {:.4f} min".format(period*2, p_e*2), transform=axes1.transAxes, color = 'C0', fontsize = 20)
axes1.text(0.66, 0.83, r" P$_r$ = {:.4f} $\pm$ {:.4f} min".format(period_r, p_e_r), transform=axes1.transAxes, color = 'C1', fontsize = 20)
axes1.text(0.45, 0.9, "LT + ZTF $g$-band", transform=axes1.transAxes, color = '0.1', fontsize = 20)
axes1.text(0.45, 0.83,"ZTF $r$-band", transform=axes1.transAxes, color = 'C1', fontsize = 20)

axes2 = fig.add_axes([0.4,0.2,0.55,0.5])

##################################################
xmajorLocator   = MultipleLocator(0.05)
xmajorFormatter = FormatStrFormatter('%.2f')
xminorLocator   = MultipleLocator(0.01)
axes2.xaxis.set_major_locator(xmajorLocator)
axes2.xaxis.set_major_formatter(xmajorFormatter)
axes2.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.1)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.02)
axes2.yaxis.set_major_locator(ymajorLocator)
axes2.yaxis.set_major_formatter(ymajorFormatter)
axes2.yaxis.set_minor_locator(yminorLocator)

axes2.set_xlim(30.11, 30.34)
axes2.set_ylim(0, 0.65)

axes2.axvline(params[1], color = '0.7', lw = 1, ls = '--')
axes2.plot(freq, power, color = '0.3', lw = 0.75)
axes2.plot(freq, power_r, color = 'C1', lw = 0.75)

axes3 = fig.add_axes([0.78,0.5,0.15,0.15])

##################################################
xmajorLocator   = MultipleLocator(0.003)
xmajorFormatter = FormatStrFormatter('%.3f')
xminorLocator   = MultipleLocator(0.001)
axes3.xaxis.set_major_locator(xmajorLocator)
axes3.xaxis.set_major_formatter(xmajorFormatter)
axes3.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.3)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.1)
axes3.yaxis.set_major_locator(ymajorLocator)
axes3.yaxis.set_major_formatter(ymajorFormatter)
axes3.yaxis.set_minor_locator(yminorLocator)

axes3.set_xlim(30.22075, 30.227)
axes3.set_ylim(0, 0.65)

axes3.axvline(params[1], color = '0.7', lw = 1, ls = '--')
axes3.axvline(params_r[1], color = 'C1', lw = 1, ls = '--')
axes3.plot(freq, power, color = '0.3', lw = 0.75)
axes3.plot(freq, power_r, color = 'C1', lw = 0.75)

axes4 = fig.add_axes([0.06,0.2,0.18,0.5])

#################################################
xmajorLocator   = MultipleLocator(2)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(0.5)
axes4.xaxis.set_major_locator(xmajorLocator)
axes4.xaxis.set_major_formatter(xmajorFormatter)
axes4.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.006)
ymajorFormatter = FormatStrFormatter('%.3f')
yminorLocator   = MultipleLocator(0.003)
axes4.yaxis.set_major_locator(ymajorLocator)
axes4.yaxis.set_major_formatter(ymajorFormatter)
axes4.yaxis.set_minor_locator(yminorLocator)


axes4.set_xlim(12.665, 18)
axes4.set_ylim(0.0, 0.018)

axes4.plot(freq, power_r, color = 'C1', lw = 0.3, alpha = 0.5)
axes4.axvline(params[1]/2.0, color = 'C0', lw = 1, ls = '--')
axes4.plot(freq, power, color = '0.3', lw = 0.3)


fal = ls.false_alarm_level([0.01])
axes1.axhline(fal, lw = 0.5, ls = '--', color = '0.5')
axes2.axhline(fal, lw = 0.5, ls = '--', color = '0.5')
axes3.axhline(fal, lw = 0.5, ls = '--', color = '0.5')
axes4.axhline(fal, lw = 0.5, ls = '--', color = '0.5')
print(fal)

plt.savefig('combined_periodogram.pdf', bbox_inches = 'tight')

plt.show()
plt.close()

