import numpy as np
import glob
import sys
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

def spec_bin(w, f, e, bin_width):
  """Bins a spectrum with a resolution of bin_width"""
  #if w[0] < 1000.0:
  #  w[:,0] *= 10
  wav_range   = max(w) - min(w)
  num_of_bins = int( np.ceil(wav_range / bin_width) )
  wb   = np.zeros(num_of_bins)
  fb   = np.zeros(num_of_bins)
  eb   = np.zeros(num_of_bins)
  temp = min(w) + (bin_width*0.5)
  for i in range(num_of_bins):
    if f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))].size != 0:
      flux_range    = f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      err_range     = e[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      wb[i], fb[i]  = temp, np.sum(flux_range*(err_range*(1/err_range.mean()))**-2)/np.sum((err_range*(1/err_range.mean()))**-2)
      eb[i]         = np.sqrt(1/np.sum(err_range**-2))
      #eb[i]         = ( np.sqrt( np.sum( (err_range)**2 ) ) ) / err_range.size
    temp          = temp + bin_width
  #
  return wb[((wb != 0) & (fb != 0) & (eb != 0))], fb[((wb != 0) & (fb != 0) & (eb != 0))], eb[((wb != 0) & (fb != 0) & (eb != 0))]

def sine(x, A, P, phi):
  return A*np.sin(2*np.pi*(x/(P) + phi))

######### Phasefold of ZTF

oid,expid,hjd,mjd,mag,magerr,catflags,filtercode,ra,dec,chi,sharp,filefracday,field,ccdid,qid,limitmag,magzp,magzprms,clrcoeff,clrcounc,exptime,airmass,programid = np.genfromtxt('J161634.36+541011.51.csv', unpack = True, delimiter = ',', skip_header = 1, dtype = 'U')
hjd    = hjd.astype(float)
mag    = mag.astype(float)
magerr = magerr.astype(float)

hjd_g, hjd_r = hjd[filtercode == 'zg'], hjd[filtercode == 'zr']
mag_g, mag_r = mag[filtercode == 'zg'], mag[filtercode == 'zr']
magerr_g, magerr_r = magerr[filtercode == 'zg'], magerr[filtercode == 'zr']



zeropoint = 0
x = np.arange(-0.001, 2.002, 0.001)
period = 95.288828 # +/- 0.000023 min From Boris Sine fit
phase_g = hjd_g / (period/(60*24)) % 1 
phase_r = hjd_r / (period/(60*24)) % 1

######### Phasefold of LT data

jd, hc, mag, error = np.genfromtxt('LT_Boris_lightcurve.dat', unpack = True, skip_header = 2)
hjd = jd + hc
mag = mag - np.median(mag)

phase_LT = hjd / (period/(60*24)) % 1


#####################################################
matplotlib.rc('font',**{'size' : 20, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
#####################################################
fig = plt.figure(figsize= (10,5))
axes1 = fig.add_axes([0,0,1,0.8])
##################################################
xmajorLocator   = MultipleLocator(0.2)
xmajorFormatter = FormatStrFormatter('%.1f')
xminorLocator   = MultipleLocator(0.05)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.05)
ymajorFormatter = FormatStrFormatter('%.2f')
yminorLocator   = MultipleLocator(0.01)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)
##################################################

axes1.set_xlabel('Phase')
axes1.set_ylabel('$\Delta$Mag')
axes1.set_xlim(0,2)
axes1.set_ylim(0.199, -0.199)
axes1.errorbar(phase_g, mag_g-np.median(mag_g), magerr_g, fmt = 'o', markersize = 3, color = 'C2', zorder = -3)
axes1.errorbar(phase_g+1, mag_g- np.median(mag_g), magerr_g, fmt = 'o', markersize = 3, color = 'C2', zorder = -3)

dmag_r = mag_r - np.median(mag_r)
print(phase_r, dmag_r,magerr_r)
plotpr, plotmag_r, plotmag_re = spec_bin(phase_r, dmag_r, magerr_r, 0.02)
axes1.errorbar(plotpr  , plotmag_r, plotmag_re, fmt = 'o', markersize = 3, color = 'C1', zorder = 2)
axes1.errorbar(plotpr+1, plotmag_r, plotmag_re, fmt = 'o', markersize = 3, color = 'C1', zorder = 2)
axes1.errorbar(phase_LT, mag, error, fmt = 'o', markersize = 3, color = '0.3', zorder = 1)
axes1.errorbar(phase_LT+1, mag, error, fmt = 'o', markersize = 3, color = '0.3',zorder = 1)

### Adding in phase of spectra
axes2 = fig.add_axes([0,0.8,1,0.2])
##################################################
xmajorLocator   = MultipleLocator(0.2)
xmajorFormatter = FormatStrFormatter('%.1f')
xminorLocator   = MultipleLocator(0.05)
axes2.xaxis.set_major_locator(xmajorLocator)
axes2.xaxis.set_major_formatter(xmajorFormatter)
axes2.xaxis.set_minor_locator(xminorLocator)
##################################################

axes2.set_facecolor("None")
axes2.xaxis.set_ticklabels([])
axes2.set_ylabel('Number')
axes2.set_xlim(0,2)
axes2.set_ylim(0, 14)
##################################################
ymajorLocator   = MultipleLocator(4)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(1)
axes2.yaxis.set_major_locator(ymajorLocator)
axes2.yaxis.set_major_formatter(ymajorFormatter)
axes2.yaxis.set_minor_locator(yminorLocator)
##################################################
##############################
plt.setp(axes2.get_yticklabels()[1], visible=False)

HJD_spec, exptime_spec = np.genfromtxt('spectra_HJD_and_exptimes.dat', comments = '#', unpack = True)
print(exptime_spec*60*24*60)
# PhaseStart and PhaseLength
ps_spec = (HJD_spec) / (period/(60*24)) % 1
pl_spec = exptime_spec / (period/(60*24))
print(pl_spec)
y = np.arange(1, HJD_spec.size + 1, 1)
axes2.axhline(2 , lw = 0.8, ls = '--', color = '0.7', zorder = -500)
axes2.axhline(4 , lw = 0.8, ls = '--', color = '0.7', zorder = -500)
axes2.axhline(6 , lw = 0.8, ls = '--', color = '0.7', zorder = -500)
axes2.axhline(8 , lw = 0.8, ls = '--', color = '0.7', zorder = -500)
axes2.axhline(10, lw = 0.8, ls = '--', color = '0.7', zorder = -500)
axes2.axhline(12, lw = 0.8, ls = '--', color = '0.7', zorder = -500)
for i in range(y.size):
  axes2.plot([ps_spec[i]    , ps_spec[i] + pl_spec[i]    ], [y[i], y[i]], color = 'C0', lw = 4, alpha = 0.5, zorder = 100)
  axes2.plot([ps_spec[i] + 1, ps_spec[i] + pl_spec[i] + 1], [y[i], y[i]], color = 'C0', lw = 4, alpha = 0.5, zorder = 100)
  axes2.plot([ps_spec[i] - 1, ps_spec[i] + pl_spec[i] - 1], [y[i], y[i]], color = 'C0', lw = 4, alpha = 0.5, zorder = 100)


r = axes1.scatter(-1000,-1000, color = 'C1', label = 'ZTF $r$ binned')
g = axes1.scatter(-1000,-1000, color = 'C2', label = 'ZTF $g$')
LT = axes1.scatter(-1000,-1000, color = '0.3', label = 'LT $g$')
DESI = axes1.plot([-1000,-999],[-1000, -999], lw = 4, alpha = 0.5, color = 'C0', label = 'DESI spectra')
axes1.legend(frameon = True, fancybox = False, loc = 'lower right', fontsize = 16).set_zorder(100)

plt.savefig('combined_phasefold_{:.10f}_split.pdf'.format(period), bbox_inches = 'tight')
plt.show()
plt.close()
