import numpy as np
import matplotlib
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 20, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 16
matplotlib.rcParams['ytick.major.pad'] = 16
#####################################################
fig = plt.figure(figsize= (6,6))


##### AXES1 #####

axes1 = fig.add_axes([0,0,1,1])
#axes1.set_xlabel('Wavelength (\AA)')

##################################################
xmajorLocator   = MultipleLocator(1)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(0.1)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(1)
ymajorFormatter = FormatStrFormatter('%d')
yminorLocator   = MultipleLocator(0.1)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)
##################################################

axes1.set_xlim(-1.5,1.5)
axes1.set_ylim(-1.5,1.5)

axes1.arrow(0,-1.5,0,3.0, color = 'black', length_includes_head = True, head_width = 0.05, lw = 1)
#axes1.arrow(-1.5,0,3.0,0, color = 'black', length_includes_head = True, head_width = 0.05, lw = 1)
axes1.text(0.05, 1.39, '$\omega$', color = 'black')
#axes1.text(1.41, -0.12, '$x$', color = 'black')
axes1.axis('off')

# Set the center of the circle
axes1.scatter(0,0,color = 'black', s = 100)


# Plotting the center of the dipole
theta = np.arange(0,2*np.pi, 0.001)
offset = 0.5
rot_ang = 45.0 * (np.pi/180)

dipole_x = -1*offset*np.sin(rot_ang)
dipole_y = offset*np.cos(rot_ang)

dipole = axes1.scatter(dipole_x, dipole_y, color = '0.0', s = 50, zorder = 1000000)
axes1.text(dipole_x + 0.03, dipole_y + 0.03, '$D$', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})

# Plotting the magnetic poles
pole = 1.0
dipole_x = -1*pole*np.sin(rot_ang)
dipole_y = pole*np.cos(rot_ang)

axes1.scatter(dipole_x, dipole_y, color = '0.0', s = 50, zorder = 100000)
axes1.text(dipole_x + 0.09, dipole_y - 0.05, '$\Theta_1$; $B$\,$\simeq$\,6.5\,MG', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})

pole = -1
dipole_x = -1*pole*np.sin(rot_ang)
dipole_y = pole*np.cos(rot_ang)

axes1.scatter(dipole_x, dipole_y, color = '0.0', s = 50, zorder = 100000)
axes1.text(dipole_x - 0.16, dipole_y - 0.25, '$\Theta_2$; $B$\,$\simeq$\,4.3\,MG', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})

# Plotting the angle between rotation axis and magnetic axis
dip_ang = np.arange(-1*rot_ang, 0, 0.001)
axes1.plot(0.1*np.sin(dip_ang), 0.1*np.cos(dip_ang), color = 'black', lw = 1)


# Plotting the white dwarf surface
x = 1*np.sin(theta)
y = 1*np.cos(theta)
axes1.plot(x,y, color = '0.3', lw = 4)

# Plotting the Magnetic Axis
lsx, lsy = 0, -1.5
lex, ley = 0, 1.5

lsx_n, lsy_n = -1*lsy*np.sin(rot_ang), lsy*np.cos(rot_ang)
lex_n, ley_n = -1*ley*np.sin(rot_ang), ley*np.cos(rot_ang)
axes1.arrow(lsx_n, lsy_n, lex_n-lsx_n, ley_n-lsy_n,color = 'black', length_includes_head = True, head_width = 0.05, lw = 1)
axes1.text(-0.09, 0.14,r'$\theta$', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})
axes1.text(lex_n +0.05, ley_n +0.05, '$z$', color = 'black', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})


# Plotting magnetic field lines

lst = [0.4,0.7,1.01,1.3,2,5,20,200]

for L in lst:
  x_old = L*np.sin(theta)*np.sin(theta)*np.sin(theta)
  y_old = L*np.sin(theta)*np.sin(theta)*np.cos(theta) + offset
  x = x_old*np.cos(rot_ang) - y_old*np.sin(rot_ang)
  y = y_old*np.cos(rot_ang) + x_old*np.sin(rot_ang)
  axes1.plot(x,y, lw = 0.8, color = '0.7', zorder = -1000, ls = '--')
  
  
# line of sight angle and plotting
los_angle = 105 *np.pi/180
los_ang = np.arange(0, los_angle, 0.001)

lsx, lsy = 0, 1.2
lex, ley = 0, 1.5
lsx_n, lsy_n = -1*lsy*np.sin(-1*los_angle), lsy*np.cos(-1*los_angle)
lex_n, ley_n = -1*ley*np.sin(-1*los_angle), ley*np.cos(-1*los_angle)
axes1.arrow(lex_n, ley_n, lsx_n-lex_n, lsy_n-ley_n,color = 'black', length_includes_head = True, head_width = 0.05, lw = 1)
axes1.text(lsx_n + 0.05, lsy_n +0.15,r'$\phi$', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})
axes1.text(lsx_n + 0.05, lsy_n -0.21,r'l.o.s.', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':0})

axes1.plot(0.1*np.sin(los_ang)+lsx_n, 0.1*np.cos(los_ang)+lsy_n, color = 'black', lw = 1)
axes1.plot([lsx_n, lsx_n], [lsy_n, lsy_n+0.2], color = '0.5', ls = '--', lw = 0.8, zorder = -100)


#axes1.arrow(0.8, -0.3, -0.8, 0.3, color = 'black', length_includes_head = True, head_width = 0.05, lw = 1)


# Plotting radius

axes1.scatter(0, 1, color = '0.0', s = 50, zorder = 100000)
axes1.text(0.05, 1.05, '$R_\mathrm{WD}$')  
  

# eyeball
#y_s = 1.2
#x_len = 0.15
#y_len = 0.06
#arc_dist = 0.5
#angle = np.arctan(0.125/(0.06 + arc_dist))
#ang_range = np.arange(-1*angle, angle, 0.001)
#plt.plot((0.03 + arc_dist)*np.sin(ang_range), -1*(0.03 + arc_dist)*np.cos(ang_range) + y_s + arc_dist - y_len*0.5, color = 'black') 
#plt.scatter(0, y_s - y_len, color = 'black', s = 50)
#cone_1_x = [0, 0 - x_len]
#cone_1_y = [y_s, y_s - y_len]
#cone_2_x = [0, 0 + x_len]
#cone_2_y = [y_s, y_s - y_len] 
#plt.plot(cone_1_x, cone_1_y, color = 'black', lw = 2)
#plt.plot(cone_2_x, cone_2_y, color = 'black', lw = 2)
  

plt.savefig('dipole_example.pdf', bbox_inches = 'tight')
plt.savefig('dipole_example.png', dpi = 600, bbox_inches = 'tight')
plt.show()
plt.close()

