import numpy as np
import matplotlib.pyplot as plt
import astropy.io.fits as fits
import glob
import scipy.interpolate
import matplotlib
from matplotlib.ticker import MultipleLocator, FormatStrFormatter
import sys
import os

bprp_final, Gabs_final, code_final = np.genfromtxt('Figure9_data.dat', unpack = True)

#Code
# 1 = 100pc WDs
# 2 = WDJ125230.93-023417.72
# 3 = WDJ121929.50+471522.94
# 4 = DESI high-conf. candidates
# 5 = DESI low-conf. candidates
# 6 = GD356
# 7 = WDJ161634.36+541011.51
# 8 = WDJ0412+7549
# 9 = SDSSJ0110--1020
# 10 = DESI DAH

#####################################################
matplotlib.rc('font',**{'size' : 22, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
#####################################################
fig = plt.figure(figsize= (12,5))
axes1 = fig.add_axes([0,0,1,1])
axes1.set_ylim((14.7,9.8))
axes1.set_xlim((-0.5,1.03))
axes1.set_xlabel(r'G$_{\textrm{BP}}$ -- G$_{\textrm{RP}}$')
axes1.set_ylabel(r'G$_{\textrm{abs}}$')


axes1.scatter(bprp_final[code_final == 1] , Gabs_final[code_final == 1] , color = '0.3', s = 0.6, edgecolors='none', zorder = -100)
axes1.scatter(bprp_final[code_final == 2] , Gabs_final[code_final == 2] , color = 'C1', marker = '^', s = 100, edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 3] , Gabs_final[code_final == 3] , color = 'C2', marker = '^', s = 100, edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 4] , Gabs_final[code_final == 4] , color = 'C0', s = 50, edgecolors='black')
axes1.scatter(bprp_final[code_final == 5] , Gabs_final[code_final == 5] , color = '0.7', marker = 'h', s = 30, edgecolors='black', zorder = -50)
axes1.scatter(bprp_final[code_final == 6] , Gabs_final[code_final == 6] , color = 'C4', s = 100, marker = '^', edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 7] , Gabs_final[code_final == 7] , color = 'C3', s = 150, marker = '*', edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 8] , Gabs_final[code_final == 8] , color = 'C5', s = 100, marker = 'p', edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 80] , Gabs_final[code_final == 80], color = 'C7', s = 100, marker = 'p', edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 9] , Gabs_final[code_final == 9] , color = 'C6', s = 50, edgecolors='black', zorder = 5000)
axes1.scatter(bprp_final[code_final == 10], Gabs_final[code_final == 10], color = 'orchid', marker = 's', s = 8, edgecolors='none', zorder = -80)

a = axes1.scatter(-1000,-1000, color = 'C3', marker = '*', s = 150, label = 'WD\,J1616+5410' , edgecolors='black')
b = axes1.scatter(-1000,-1000, color = 'C1', marker = '^', s = 100, label = 'WD\,J1252--0234', edgecolors='black')
c = axes1.scatter(-1000,-1000, color = 'C4', marker = '^', s = 100, label = 'GD356'   , edgecolors='black')
d = axes1.scatter(-1000,-1000, color = 'C2', marker = '^', s = 100, label = 'WD\,J1219+4715' , edgecolors='black')
e = axes1.scatter(-1000,-1000, color = 'C5', marker = 'p', s = 100, label = 'WD\,J0412+7549' , edgecolors='black')
e1 = axes1.scatter(-1000,-1000, color = 'C7', marker = 'p', s = 100, label = 'WD\,J1653--1001' , edgecolors='black')
f = axes1.scatter(-1000,-1000, color = 'C6', label = 'SDSS DAHe' , edgecolors='black')
g = axes1.scatter(-1000,-1000, color = 'C0', label = 'DESI DAHe'                , edgecolors='black')
h = axes1.scatter(-1000,-1000, color = '0.7' ,marker = 'h', label = 'DESI DAHe candidate'                , edgecolors='black')
gaia    = axes1.scatter(-1000,-1000, color = '0.3', label = 'WD candidates within 100pc'         , edgecolors='None')
j =   axes1.scatter(-1000, -1000, color = 'orchid', marker = 's', s = 8, edgecolors='none', zorder = -80, label = 'DESI DAH')
first_legend = axes1.legend(frameon = True, fontsize = 14, handles = [c,d,b,a,e,e1,g,f,j,h])
ax = plt.gca().add_artist(first_legend)  

#Defining cut regions
xa, ya = 36.0/385.0, 5101.0/385.0
xb, yb = 114.0/385.0, 9617.0/770.0
xc, yc = 48.0/77.0, 10289.0/770.0
xd, yd = 162.0/385.0, 5437.0/385.0
xrange1 = np.arange(xa, xb + 0.0001, 0.0001)
xrange2 = np.arange(xb, xc + 0.0001, 0.0001)
xrange3 = np.arange(xd, xc + 0.0001, 0.0001)
xrange4 = np.arange(xa, xd + 0.0001, 0.0001)
axes1.plot(xrange1, -3.75*xrange1 + 13.6, color = '0.5', lw = 0.8, zorder = 100)
axes1.plot(xrange2, (8.0/3.0)*xrange2 + 11.7, color = '0.5', lw = 0.8, zorder = 100)
axes1.plot(xrange3, -3.75*xrange3 + 15.7, color = '0.5', lw = 0.8, zorder = 100)
axes1.plot(xrange4, (8.0/3.0)*xrange4 + 13.0, color = '0.5', lw = 0.8, zorder = 100)

M2, T2, G2, BPRP2 = np.genfromtxt('crys_sequence_frac_0.2_thick.txt', unpack = True)
M2, T8, G8, BPRP8 = np.genfromtxt('crys_sequence_frac_0.8_thick.txt', unpack = True)

one = axes1.plot(BPRP2, G2, color = 'red', lw = 0.8, label = 'thick H atmosphere', zorder = 5000000)
axes1.plot(BPRP8, G8, color = 'red', lw = 0.8, zorder = 5000000)

#M1, T1, G1, BPRP1 = np.genfromtxt(cryspath + 'crys_sequence_frac_0.1_thin.txt', unpack = True)
M2, T2, G2, BPRP2 = np.genfromtxt('crys_sequence_frac_0.2_thin.txt', unpack = True)
M2, T8, G8, BPRP8 = np.genfromtxt('crys_sequence_frac_0.8_thin.txt', unpack = True)

#axes1.plot(BPRP1, G1, color = 'red', lw = 0.8, ls = '--')
two = axes1.plot(BPRP2, G2, color = 'red', lw = 0.8, ls = '--', label = 'thin H atmosphere' , zorder = 5000000)
axes1.plot(BPRP8, G8, color = 'red', lw = 0.8, ls = '--', zorder = 5000000)

p6RP = np.genfromtxt('Table_Mass_0p6.dat', skip_header = 2, usecols = -7)
p6BP = np.genfromtxt('Table_Mass_0p6.dat', skip_header = 2, usecols = -8)
p6G = np.genfromtxt('Table_Mass_0p6.dat', skip_header = 2, usecols = -9)
p6BPRP = p6BP - p6RP

axes1.plot(p6BPRP, p6G, color = '0.1', ls = ':', lw = 1, zorder = -1000000)

p8RP = np.genfromtxt('Table_Mass_0p8.dat', skip_header = 2, usecols = -7)
p8BP = np.genfromtxt('Table_Mass_0p8.dat', skip_header = 2, usecols = -8)
p8G  = np.genfromtxt('Table_Mass_0p8.dat', skip_header = 2, usecols = -9)
p8BPRP = p8BP - p8RP

axes1.plot(p8BPRP, p8G, color = '0.1', ls = ':', lw = 1, zorder = -1000000)

p10RP = np.genfromtxt('Table_Mass_1p0.dat', skip_header = 2, usecols = -7)
p10BP = np.genfromtxt('Table_Mass_1p0.dat', skip_header = 2, usecols = -8)
p10G  = np.genfromtxt('Table_Mass_1p0.dat', skip_header = 2, usecols = -9)
p10BPRP = p10BP - p10RP

axes1.plot(p10BPRP, p10G, color = '0.1', ls = ':', lw = 1, zorder = -1000000)


axes1.text(0.05, 0.95, '0.6\,M$_\odot$', transform=axes1.transAxes, fontsize = 12, bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes1.text(0.02, 0.88, '0.8\,M$_\odot$', transform=axes1.transAxes, fontsize = 12, bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
axes1.text(0.02, 0.765, '1.0\,M$_\odot$', transform=axes1.transAxes, fontsize = 12, bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})


#axes1.legend(frameon = False, fontsize = 14, handles = [one,two])
plt.savefig('mag_HR_long.pdf', bbox_inches = 'tight')
axes1.set_ylim((14.7,12))
axes1.set_xlim((-0.1,1.03))
plt.savefig('mag_HR_zoom.pdf', bbox_inches = 'tight')
plt.show()
plt.close()