import numpy as np
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter
import scipy.interpolate

def spec_bin(w, f, e, bin_width):
  """Bins a spectrum with a resolution of bin_width"""
  if w[0] < 1000.0:
    w[:,0] *= 10
  wav_range   = max(w) - min(w)
  num_of_bins = int( np.ceil(wav_range / bin_width) )
  wb   = np.zeros(num_of_bins)
  fb   = np.zeros(num_of_bins)
  eb   = np.zeros(num_of_bins)
  temp = min(w) + (bin_width*0.5)
  for i in range(num_of_bins):
    if f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))].size != 0:
      flux_range    = f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      err_range     = e[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      wb[i], fb[i]  = temp, np.sum(flux_range*(err_range*(1/err_range.mean()))**-2)/np.sum((err_range*(1/err_range.mean()))**-2)
      eb[i]         = np.sqrt(1/np.sum(err_range**-2))
    temp          = temp + bin_width
  #
  return wb[((wb != 0) & (fb != 0) & (eb != 0))], fb[((wb != 0) & (fb != 0) & (eb != 0))], eb[((wb != 0) & (fb != 0) & (eb != 0))]
  

system_name = ['whole_SDSS_WDJ143657.48+210714.67_spec-02788-54553-0593_norm','whole_SDSS_WDJ122619.77+183634.46_spec-02598-54232-0363_norm','whole_SDSS_WDJ101949.67+114148.73_spec-01598-53033-0337_norm','whole_DESI_WDJ150057.83+484002.41_bin0p2_norm','whole_DESI_WDJ075224.17+472422.44_bin0p2_norm','whole_DESI_WDJ041926.91-011333.28_bin0p2_norm','whole_DESI_WDJ001319.16+240111.02_bin0p2_norm','whole_DESI_WDJ002844.20+055931.27_bin0p2_norm','whole_DESI_WDJ063357.87+561413.12_bin0p2_norm','whole_DESI_WDJ073227.97+662310.18_bin0p2_norm','whole_DESI_WDJ075429.35+661106.64_bin0p2_norm','whole_DESI_WDJ082337.16+383816.50_bin0p2_norm','whole_DESI_WDJ132035.85+324925.05_bin0p2_norm','whole_DESI_WDJ140916.34-000011.32_bin0p2_norm','whole_DESI_WDJ144626.01+282600.21_bin0p2_norm','whole_DESI_WDJ145207.19+325240.45_bin0p2_norm','whole_DESI_WDJ155807.89+381649.61_bin0p2_norm','whole_DESI_WDJ171101.52+654549.87_bin0p2_norm','whole_SDSS_SDSSJ011027.50-102008.6_nobin_norm', 'whole_DESI_WDJ175611.14+335230.75_4604672031893282176_Guadalupe_bin0p2_norm']
magfield = [60.0,11.5,10.5, 19,21,34,42.3,45.2,116.2,99.1,56.1,18.7,146.5,23.5,7.3,14.2,18.4,37.7,9.3, 13.6]

for i in range(len(system_name)):
  #####################################################
  ################## Plotting section #################
  #####################################################
  matplotlib.rc('font',**{'size' : 16, 'family':'serif',
  'serif':['serif']})
  matplotlib.rcParams['text.usetex'] = True
  matplotlib.rcParams['ps.fonttype'] = 42
  matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
  matplotlib.rcParams['xtick.major.pad'] = 10
  matplotlib.rcParams['ytick.major.pad'] = 10
  #####################################################
  fig = plt.figure(figsize= (10,3))
  axes1 = fig.add_axes([0,0,1,1])

  ##################################################
  xmajorLocator   = MultipleLocator(500)
  xmajorFormatter = FormatStrFormatter('%d')
  xminorLocator   = MultipleLocator(100)
  axes1.xaxis.set_major_locator(xmajorLocator)
  axes1.xaxis.set_major_formatter(xmajorFormatter)
  axes1.xaxis.set_minor_locator(xminorLocator)
  ##################################################
  datfile = '{:s}.dat'.format(system_name[i])
  name = system_name[i].split('_')[2].split('J')[-1]
  if system_name[i].split('_')[2].split('J')[0] == 'WD':
    name = 'WD\,J' + name
  else:
    name = 'SDSS\,J' + name
  wave, flux, err = np.genfromtxt(datfile, unpack = True)
  plotwave, plotflux, ploterror = spec_bin(wave, flux, err, 2.0)
  axes1.plot(plotwave, plotflux*magfield[i], color = '0.3', lw = 0.8)
  
  for j in range(1,15):
    w, B = np.genfromtxt('alpha_{:d}.txt'.format(j), unpack = True)
    axes1.plot(w,B,lw = 0.5, color = 'C1', zorder = -5, alpha = 0.5)
  for j in range(1,18):
    w, B = np.genfromtxt('beta_{:d}.txt'.format(j), unpack = True)
    axes1.plot(w,B,lw = 0.5, color = 'C0', zorder = -5, alpha = 0.5)
    
  axes1.text(0.01, 0.9, name, transform=axes1.transAxes, color = '0.1', fontsize = 20, bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1}, zorder = 100) 
  axes1.axhline(magfield[i], color = '0.5', lw = 0.5, ls = '--', zorder = -20) 
  axes1.set_xlabel('Wavelength (\AA)')
  axes1.set_ylabel('B (MG)')
  axes1.set_xlim(3700,8500)
  axes1.set_ylim(magfield[i]*0.5,magfield[i]*1.5)
  plt.savefig(datfile[:-4] + '_mag.pdf', bbox_inches = 'tight')
  plt.close()