import numpy as np
import glob
import sys
import matplotlib
#matplotlib.use('PS')
import matplotlib.pyplot as plt
from matplotlib.ticker import MultipleLocator, FormatStrFormatter

def spec_bin(w, f, e, bin_width):
  """Bins a spectrum with a resolution of bin_width"""
  if w[0] < 1000.0:
    w[:,0] *= 10
  wav_range   = max(w) - min(w)
  num_of_bins = int( np.ceil(wav_range / bin_width) )
  wb   = np.zeros(num_of_bins)
  fb   = np.zeros(num_of_bins)
  eb   = np.zeros(num_of_bins)
  temp = min(w) + (bin_width*0.5)
  for i in range(num_of_bins):
    if f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))].size != 0:
      flux_range    = f[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      err_range     = e[(w >= (temp-bin_width*0.5)) & (w < (temp+bin_width*0.5))]
      wb[i], fb[i]  = temp, np.sum(flux_range*(err_range*(1/err_range.mean()))**-2)/np.sum((err_range*(1/err_range.mean()))**-2)
      eb[i]         = np.sqrt(1/np.sum(err_range**-2))
      #eb[i]         = ( np.sqrt( np.sum( (err_range)**2 ) ) ) / err_range.size
    temp          = temp + bin_width
  #
  return wb[((wb != 0) & (fb != 0) & (eb != 0))], fb[((wb != 0) & (fb != 0) & (eb != 0))], eb[((wb != 0) & (fb != 0) & (eb != 0))]
  

#####################################################
################## Plotting section #################
#####################################################
matplotlib.rc('font',**{'size' : 16, 'family':'serif',
'serif':['serif']})
matplotlib.rcParams['text.usetex'] = True
matplotlib.rcParams['ps.fonttype'] = 42
matplotlib.rcParams['ps.usedistiller'] = 'xpdf'
matplotlib.rcParams['xtick.major.pad'] = 10
matplotlib.rcParams['ytick.major.pad'] = 10
#####################################################
fig = plt.figure(figsize= (8,10))
axes1 = fig.add_axes([0,0,0.24,1])
axes2 = fig.add_axes([0.24,0,0.24,1])

axes3 = fig.add_axes([0.52,0,0.24,1])
axes4 = fig.add_axes([0.76,0,0.24,1])

##################################################
xmajorLocator   = MultipleLocator(100)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(50)
axes1.xaxis.set_major_locator(xmajorLocator)
axes1.xaxis.set_major_formatter(xmajorFormatter)
axes1.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.5)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.1)
axes1.yaxis.set_major_locator(ymajorLocator)
axes1.yaxis.set_major_formatter(ymajorFormatter)
axes1.yaxis.set_minor_locator(yminorLocator)
##################################################
##################################################
xmajorLocator   = MultipleLocator(250)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(125)
axes2.xaxis.set_major_locator(xmajorLocator)
axes2.xaxis.set_major_formatter(xmajorFormatter)
axes2.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.5)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.1)
axes2.yaxis.set_major_locator(ymajorLocator)
axes2.yaxis.set_major_formatter(ymajorFormatter)
axes2.yaxis.set_minor_locator(yminorLocator)
##################################################
##################################################
xmajorLocator   = MultipleLocator(100)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(50)
axes3.xaxis.set_major_locator(xmajorLocator)
axes3.xaxis.set_major_formatter(xmajorFormatter)
axes3.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.5)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.1)
axes3.yaxis.set_major_locator(ymajorLocator)
axes3.yaxis.set_major_formatter(ymajorFormatter)
axes3.yaxis.set_minor_locator(yminorLocator)
##################################################
##################################################
xmajorLocator   = MultipleLocator(250)
xmajorFormatter = FormatStrFormatter('%d')
xminorLocator   = MultipleLocator(125)
axes4.xaxis.set_major_locator(xmajorLocator)
axes4.xaxis.set_major_formatter(xmajorFormatter)
axes4.xaxis.set_minor_locator(xminorLocator)

ymajorLocator   = MultipleLocator(0.5)
ymajorFormatter = FormatStrFormatter('%.1f')
yminorLocator   = MultipleLocator(0.1)
axes4.yaxis.set_major_locator(ymajorLocator)
axes4.yaxis.set_major_formatter(ymajorFormatter)
axes4.yaxis.set_minor_locator(yminorLocator)
##################################################

#axes1.set_xlim(3500, 10000)
axes1.set_xlim(4660, 5049.99)
axes2.set_xlim(6140, 6990)
axes1.axvline(4861, color = '0.5', lw = 0.8, ls = '--')
axes2.axvline(6563, color = '0.5', lw = 0.8, ls = '--')
axes3.set_xlim(4660, 5049.99)
axes4.set_xlim(6140, 6990)
axes3.axvline(4861, color = '0.5', lw = 0.8, ls = '--')
axes4.axvline(6563, color = '0.5', lw = 0.8, ls = '--')
axes2.yaxis.set_ticklabels([])
axes3.yaxis.set_ticklabels([])
axes4.yaxis.set_ticklabels([])
plt.setp(axes2.get_xticklabels()[1], visible=False)
plt.setp(axes4.get_xticklabels()[1], visible=False)


axes1.set_xlabel('Wavelength (\AA)')
axes2.set_xlabel('Wavelength (\AA)')
axes3.set_xlabel('Wavelength (\AA)')
axes4.set_xlabel('Wavelength (\AA)')
axes1.set_ylabel('Normalised Flux')

spec_b_lst = sorted(glob.glob('*-b_norm.dat'))
spec_r_lst = sorted(glob.glob('*-r_norm.dat'))
step1 = 0
offset1 = 0.35
step2 = 0
offset2 = 0.35
for i in range(len(spec_b_lst)):
  wavb, fluxb, errb = np.genfromtxt(spec_b_lst[12-i], unpack = True)
  wavr, fluxr, errr = np.genfromtxt(spec_r_lst[12-i], unpack = True)
  pwb, pfb, peb = spec_bin(wavb, fluxb, errb, 2)
  pwr, pfr, per = spec_bin(wavr, fluxr, errr, 2)
  if i < 6:
    axes3.plot(pwb, pfb + step1, color = '0.3', lw = 1)
    axes4.plot(pwr, pfr + step1, color = '0.3', lw = 1)
    axes3.text(4670, 1.13 + step1, r'\#{:d}'.format(13-i), color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
    step1 += offset1
  else:
    axes1.plot(pwb, pfb + step2, color = '0.3', lw = 1)
    axes2.plot(pwr, pfr + step2, color = '0.3', lw = 1)
    axes1.text(4670, 1.13 + step2, r'\#{:d}'.format(13-i), color = '0.3', bbox={'edgecolor':'white', 'facecolor':'white', 'alpha':1, 'pad':1})
    step2 += offset2

axes1.set_ylim(0.8,3.4)
axes2.set_ylim(0.8,3.4)
axes3.set_ylim(0.8,3.4)
axes4.set_ylim(0.8,3.4)


axes1.text(0.54, 0.97, r'H$\beta$', transform=axes1.transAxes, color = '0.3')
axes2.text(0.52, 0.97, r'H$\alpha$', transform=axes2.transAxes, color = '0.3')
axes3.text(0.54, 0.97, r'H$\beta$', transform=axes3.transAxes, color = '0.3')
axes4.text(0.52, 0.97, r'H$\alpha$', transform=axes4.transAxes, color = '0.3')

plt.savefig('spectra_all.pdf', bbox_inches = 'tight')
plt.show()
plt.close()